summaryrefslogtreecommitdiff
path: root/psutil/_psosx.py
diff options
context:
space:
mode:
authorGiampaolo Rodola <g.rodola@gmail.com>2020-12-21 01:20:18 +0100
committerGiampaolo Rodola <g.rodola@gmail.com>2020-12-21 01:20:18 +0100
commita4c0a0eb0d2a872ab7a45e47fcf37ef1fde5b012 (patch)
treee3d5b78fef7d6ecbbd292e0f081283eaefec5ffb /psutil/_psosx.py
parent58c4b1f83c531c0c61d153eb85eb8c7cac2e3449 (diff)
downloadpsutil-a4c0a0eb0d2a872ab7a45e47fcf37ef1fde5b012.tar.gz
Rename cpu_count_physical() to cpu_count_cores()
This has always been cause of confusion, e.g. see: https://github.com/giampaolo/psutil/pull/1727#issuecomment-698934643 Removed the reference to "physical" from dostrings, functions and test. I still left it in the doc though, as it's more explanatory. Signed-off-by: Giampaolo Rodola <g.rodola@gmail.com>
Diffstat (limited to 'psutil/_psosx.py')
-rw-r--r--psutil/_psosx.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/psutil/_psosx.py b/psutil/_psosx.py
index c7770d65..d948cc15 100644
--- a/psutil/_psosx.py
+++ b/psutil/_psosx.py
@@ -159,9 +159,9 @@ def cpu_count_logical():
return cext.cpu_count_logical()
-def cpu_count_physical():
- """Return the number of physical CPUs in the system."""
- return cext.cpu_count_phys()
+def cpu_count_cores():
+ """Return the number of CPU cores in the system."""
+ return cext.cpu_count_cores()
def cpu_stats():